;/*************************************************************************/
;/*                                                                       */
;/*                Institut fr Maschinelle Sprachverarbeitung            */
;/*                     University of Stuttgart, Germany                  */
;/*                         Copyright (c) 1998                            */
;/*                        All Rights Reserved.                           */
;/*                                                                       */
;/*  Permission to use, copy, modify, distribute this software and its    */
;/*  documentation for research, educational and individual use only, is  */
;/*  hereby granted without fee, subject to the following conditions:     */
;/*   1. The code must retain the above copyright notice, this list of    */
;/*      conditions and the following disclaimer.                         */
;/*   2. Any modifications must be clearly marked as such.                */
;/*   3. Original authors' names are not deleted.                         */
;/*   4. It may not be redistributed in a modified version or within      */
;/*      another distribution                                             */
;/*  This software may not be used for commercial purposes without        */
;/*  specific prior written permission from the authors.                  */
;/*                                                                       */
;/*  THE UNIVERSITY OF STUTTGART AND THE CONTRIBUTORS TO THIS WORK        */
;/*  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      */
;/*  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   */
;/*  SHALL THE UNIVERSITY OF STUTTGART NOR THE CONTRIBUTORS BE LIABLE     */
;/*  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    */
;/*  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   */
;/*  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          */
;/*  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       */
;/*  THIS SOFTWARE.                                                       */
;/*                                                                       */
;/*************************************************************************/
;/*             Author : Gregor Mhler (moehler@ims.uni-stuttgart.de)     */
;/*-----------------------------------------------------------------------*/
;/*                                                                       */
;/* Principal file for German duration modelling.                         */
;/* Contains data for the zscore duration model and for a simple duration */
;/* model based on mean durations                                         */
;/*                                                                       */
;/*=======================================================================*/

;zscore-duration method

(require 'ims_german_duration_zscoretree)  ; CART tree predicted by wagon 

; in german_voices.scm to provide zscore-duration:
; (Parameter.set 'Duration_Method 'Tree_ZScores)
; (set! duration_cart_tree german_duration_cart_tree);
; (set! duration_ph_info german_duration_ph_info)

(set! german_duration_ph_info
 '(
    (6   0.0588612310823315   41.3445293990342  ) ; examples in db: 1081
   ;(@   0.0613695752590675  100.108582515932   ) ; examples in db: 2316
    (@   0.0613695752590675   30                ) ; corrected
    (i:  0.0853213138722557   43.51598260073    ) ; examples in db: 1002
    (I   0.0647806882441599   37.9842561803385  ) ; examples in db: 1327
    (y:  0.0919568631901841    7.62868035666795 ) ; examples in db: 163
    (Y   0.0496796230769231    2.95367354491886 ) ; examples in db: 156
    (e:  0.0744900650090418   43.234199274894   ) ; examples in db: 1106
    (E   0.0665194029061107   46.0104144715357  ) ; examples in db: 1342
    (E:  0.0938930809160305    3.92186294901072 ) ; examples in db: 131
    (2:  0.120968074193548     1.25223763523222 ) ; examples in db: 31
    (9   0.0726668066666667    0.654835825613873) ; examples in db: 30
    (u:  0.129624177443609    13.5941530530981  ) ; examples in db: 266
    (U   0.0763385361308676   24.5277856103262  ) ; examples in db: 703
    (o:  0.0932197174840086   21.0615261456664  ) ; examples in db: 469
    (O   0.0878181485454544   17.2081497729911  ) ; examples in db: 550
    (a:  0.129607736106984    31.3227404359422  ) ; examples in db: 673
    (a   0.0925457660682228   35.3695945483421  ) ; examples in db: 1114
    (aI  0.132335570954907    32.6308620917977  ) ; examples in db: 754
    (OY  0.12027191576087      5.31361083978328 ) ; examples in db: 184
    (aU  0.160493883805668    11.0027570595657  ) ; examples in db: 247
    (p   0.0700943601415095    9.75998758834242 ) ; examples in db: 424
    (b   0.0573850729136164   14.6944184666198  ) ; examples in db: 683
    (t   0.0655159743798121   71.3116289521574  ) ; examples in db: 2338
    (d   0.0454063011771999   41.2232927856527  ) ; examples in db: 1614
    (k   0.0713219087786258   21.8946169222564  ) ; examples in db: 786
    (g   0.0456017105263158   12.9183034127605  ) ; examples in db: 703
    (f   0.0839157727361248   33.2769999869762  ) ; examples in db: 1027
    (v   0.0617552588235294   16.2000179543673  ) ; examples in db: 527
    (s   0.0903387463515756   46.0695024958858  ) ; examples in db: 1206
    (z   0.0819970244744743   15.1915851148355  ) ; examples in db: 666
    (S   0.0871598007889546   13.3631217697957  ) ; examples in db: 507
    (Z   0.0685714714285714    0.152690336492935) ; examples in db: 7
    (x   0.0636808654255319    4.44708728086053 ) ; examples in db: 188
    (C   0.0745084635491607   15.4489503831762  ) ; examples in db: 417
    (h   0.0521598971786834   12.5341285681593  ) ; examples in db: 319
    (pf  0.12                  0.18834930869536 ) ; corrected
   ;(pf  0.0375001             0.18834930869536 ) ; examples in db: 12
    (ts  0.10                 11.6986288511783  ) ; corrected
   ;(ts  0.0461348651388889   11.6986288511783  ) ; examples in db: 720
    (tS  0.12                  0.358043351806697) ; corrected
   ;(tS  0.0424241272727273    0.358043351806697) ; examples in db: 33
    (m   0.0714792332917705   23.331501790663   ) ; examples in db: 802
   ;(n   0.0711688705274902  154.241241672127   ) ; examples in db: 3583
    (n   0.0711688705274902   15                ) ; corrected
    (N   0.0928133777158775   16.8922221470096  ) ; examples in db: 359
    (l   0.044465900791557    23.694669626684   ) ; examples in db: 1137
    (R   0.0461701407520332   48.166751082736   ) ; examples in db: 1968
    (j   0.0833870322580645    3.42039619650901 ) ; examples in db: 62
    (_   0.538435629479769   315.081417334377   ) ; examples in db: 865
    (a^  0.1                  10                ) ; no ex. in db: handcrafted
    (o^  0.1                  10                ) ; no ex. in db: handcrafted
    (E^  0.1                  10                ) ; no ex. in db: handcrafted
    (dZ^ 0.1                  10                ) ; no ex. in db: handcrafted
    (?   0.003                 1                ) ; no ex. in db: handcrafted
  )
)


(set! german_duration_ph_info_sampa
 '(
    (6  0.0588612310823315   41.3445293990342  ) ; examples in db: 1081
   ;(@  0.0613695752590675  100.108582515932   ) ; examples in db: 2316
    (@  0.0613695752590675   30                ) ; corrected
    (i: 0.0853213138722557   43.51598260073    ) ; examples in db: 1002
    (I  0.0647806882441599   37.9842561803385  ) ; examples in db: 1327
    (y: 0.0919568631901841    7.62868035666795 ) ; examples in db: 163
    (Y  0.0496796230769231    2.95367354491886 ) ; examples in db: 156
    (e: 0.0744900650090418   43.234199274894   ) ; examples in db: 1106
    (E  0.0665194029061107   46.0104144715357  ) ; examples in db: 1342
    (E: 0.0938930809160305    3.92186294901072 ) ; examples in db: 131
    (2: 0.120968074193548     1.25223763523222 ) ; examples in db: 31
    (9  0.0726668066666667    0.654835825613873) ; examples in db: 30
    (u: 0.129624177443609    13.5941530530981  ) ; examples in db: 266
    (U  0.0763385361308676   24.5277856103262  ) ; examples in db: 703
    (o: 0.0932197174840086   21.0615261456664  ) ; examples in db: 469
    (O  0.0878181485454544   17.2081497729911  ) ; examples in db: 550
    (a: 0.129607736106984    31.3227404359422  ) ; examples in db: 673
    (a  0.0925457660682228   35.3695945483421  ) ; examples in db: 1114
    (aI 0.132335570954907    32.6308620917977  ) ; examples in db: 754
    (OY 0.12027191576087      5.31361083978328 ) ; examples in db: 184
    (aU 0.160493883805668    11.0027570595657  ) ; examples in db: 247
    (eI 0.1                  30                ) ; handcrafted
    (w  0.08                 30                ) ; handcrafted
    (o  0.05                 30                ) ; handcrafted
    (u  0.05                 30                ) ; handcrafted
    (i  0.05                 30                ) ; handcrafted
    (e  0.05                 30                ) ; handcrafted
    (y  0.05                 30                ) ; handcrafted
    (O: 0.1                  30                ) ; handcrafted
    (9: 0.1                  30                ) ; handcrafted
    (p  0.0700943601415095    9.75998758834242 ) ; examples in db: 424
    (b  0.0573850729136164   14.6944184666198  ) ; examples in db: 683
    (t  0.0655159743798121   71.3116289521574  ) ; examples in db: 2338
    (d  0.0454063011771999   41.2232927856527  ) ; examples in db: 1614
    (k  0.0713219087786258   21.8946169222564  ) ; examples in db: 786
    (g  0.0456017105263158   12.9183034127605  ) ; examples in db: 703
    (f  0.0839157727361248   33.2769999869762  ) ; examples in db: 1027
    (v  0.0617552588235294   16.2000179543673  ) ; examples in db: 527
    (s  0.0903387463515756   46.0695024958858  ) ; examples in db: 1206
    (z  0.0819970244744743   15.1915851148355  ) ; examples in db: 666
    (S  0.0871598007889546   13.3631217697957  ) ; examples in db: 507
    (Z  0.0685714714285714    0.152690336492935) ; examples in db: 7
    (x  0.0636808654255319    4.44708728086053 ) ; examples in db: 188
    (C  0.0745084635491607   15.4489503831762  ) ; examples in db: 417
    (h  0.0521598971786834   12.5341285681593  ) ; examples in db: 319
    (T  0.09                 30                ) ; handcrafted
    (D  0.08                 30                ) ; handcrafted
    (pf 0.12                  0.18834930869536 ) ; corrected
   ;(pf 0.0375001             0.18834930869536 ) ; examples in db: 12
    (ts 0.10                 11.6986288511783  ) ; corrected
   ;(ts 0.0461348651388889   11.6986288511783  ) ; examples in db: 720
    (tS 0.12                  0.358043351806697) ; corrected
   ;(tS 0.0424241272727273    0.358043351806697) ; examples in db: 33
    (dZ 0.03                 20                ) ; corrected 
    (m  0.0714792332917705   23.331501790663   ) ; examples in db: 802
   ;(n  0.0711688705274902  154.241241672127   ) ; examples in db: 3583
    (n  0.0711688705274902   15                ) ; corrected
    (N  0.0928133777158775   16.8922221470096  ) ; examples in db: 359
    (l  0.044465900791557    23.694669626684   ) ; examples in db: 1137
    (R  0.0461701407520332   48.166751082736   ) ; examples in db: 1968
    (j  0.0833870322580645    3.42039619650901 ) ; examples in db: 62
   ;(_  0.538435629479769   315.081417334377   ) ; examples in db: 865
    (_  0.2                 100                )
    (a~ 0.1                  10                ) ; handcrafted
    (e~ 0.1                  10                ) ; handcrafted
    (9~ 0.1                  10                ) ; handcrafted
    (?  0.003                 1                ) ; handcrafted
  )
)


; for simple method:
(set! german_dur_tree
 '((Syllable.p.syl_break > 1) ; clause initial
   ((Syllable.stress is 1)
    ((1.0))
    ((1.0)))
   ((Syllable.syl_break > 1)  ; clause final
    ((Syllable.stress is 1)
     ((1.0))
     ((1.0)))
    ((Syllable.stress is 1)
     ((1.0))
     ((1.0))))))


; data from IMS German News Corpus
(set! german_de1_phone_data
 '(
    (OY 0.0 0.1218)
    (aI 0.0 0.1000) ; corr
    (aU 0.0 0.1000) ; corr
    (_  0.0 0.5120)
    (?  0.0 0.0300)
    (f  0.0 0.0500) ; corr
    (v  0.0 0.0533)
    (s  0.0 0.0859)
    (pf 0.0 0.0900)
    (ts 0.0 0.1500)
    (tS 0.0 0.0900)
    (z  0.0 0.0826)
    (S  0.0 0.0831)
    (Z  0.0 0.0722)
    (C  0.0 0.1000) ; corr
    (j  0.0 0.0757)
    (x  0.0 0.0734)
    (h  0.0 0.0481)
    (l  0.0 0.0418)
    (R  0.0 0.0443)
    (i: 0.0 0.1200) ; corr
    (e: 0.0 0.0730)
    (E: 0.0 0.0929)
    (a: 0.0 0.1266)
    (o: 0.0 0.0938)
    (u: 0.0 0.0968)
    (y: 0.0 0.0892)
    (2: 0.0 0.1074)
    (N  0.0 0.0949)
    (m  0.0 0.0692)
    (n  0.0 0.0716)
    (p  0.0 0.0657)
    (b  0.0 0.0561)
    (t  0.0 0.0600)
    (d  0.0 0.0445)
    (k  0.0 0.0695)
    (g  0.0 0.0448)
    (@  0.0 0.0607)
    (6  0.0 0.0500)
    (I  0.0 0.0601)
    (E  0.0 0.0630)
    (a  0.0 0.0908)
    (O  0.0 0.0880)
    (U  0.0 0.0730)
    (Y  0.0 0.0499)
    (9  0.0 0.0730)
    (E^ 0.0 0.1100)
    (a^ 0.0 0.1100)
    (o^ 0.0 0.1100)
    (E~ 0.0 0.0900)
    (a~ 0.0 0.0900)
    (o~ 0.0 0.0900)
  )
)


(provide 'ims_german_duration)
