;/*************************************************************************/
;/*                                                                       */
;/*                Institut fr Maschinelle Sprachverarbeitung            */
;/*                     University of Stuttgart, Germany                  */
;/*                         Copyright (c) 1998                            */
;/*                        All Rights Reserved.                           */
;/*                                                                       */
;/*  Permission to use, copy, modify, distribute this software and its    */
;/*  documentation for research, educational and individual use only, is  */
;/*  hereby granted without fee, subject to the following conditions:     */
;/*   1. The code must retain the above copyright notice, this list of    */
;/*      conditions and the following disclaimer.                         */
;/*   2. Any modifications must be clearly marked as such.                */
;/*   3. Original authors' names are not deleted.                         */
;/*   4. It may not be redistributed in a modified version or within      */
;/*      another distribution                                             */
;/*  This software may not be used for commercial purposes without        */
;/*  specific prior written permission from the authors.                  */
;/*                                                                       */
;/*  THE UNIVERSITY OF STUTTGART AND THE CONTRIBUTORS TO THIS WORK        */
;/*  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      */
;/*  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   */
;/*  SHALL THE UNIVERSITY OF STUTTGART NOR THE CONTRIBUTORS BE LIABLE     */
;/*  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    */
;/*  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   */
;/*  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          */
;/*  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       */
;/*  THIS SOFTWARE.                                                       */
;/*                                                                       */
;/*************************************************************************/
;/*             Author :  Gregor Mhler (moehler@ims.uni-stuttgart.de)    */
;/*-----------------------------------------------------------------------*/
;/*                                                                       */
;/* This file defines the German token module ``German_Token''            */
;/* and sets the end-of-utterance tree for German (``german_eou_tree'').  */
;/*                                                                       */
;/*=======================================================================*/



(require 'ims_german_token_to_words)

;; using a lisp function instead of C++ to do the German Token Module
(define (Token_German utt)
"(Token_German UTT) German version of Token"
(mapcar 
 (lambda (tok)
;   (format t "Das ist tok: %s" (item.name tok)) (terpri)
   (german_fill_tokenrelation utt tok  (german_token_to_words tok (symbol->string(item.name tok)))))
 (utt.relation.items utt 'Token)))



(define (german_fill_tokenrelation utt token wordlist)
"(german_fill_tokenrelation UTT TOKEN WORDLIST) adds the words from WORDLIST
as item to the Word relation of utterance UTT, 
relating the new Word to the Token TOKEN"

(cond
 ((not(null? wordlist))
  (if (not(utt.relation.present utt 'Word)) 
      (utt.relation.create utt 'Word))
    
  (utt.relation.append utt 'Word)
  (let ((wrd (utt.relation.last utt 'Word)))
    (item.set_name wrd (car wordlist))
    (item.append_daughter token wrd))
  (german_fill_tokenrelation utt token (cdr wordlist)))))




; for german we need an other eou_tree because of ordinal numbers.

;(set! german_eou_tree
(defvar german_eou_tree
  '((n.whitespace matches ".*\n.*\n\\(.\\|\n\\)*") ;; A significant break (2 nls)
    ((1))
    ((punc in ("?" ":" "!"))
     ((1))
     ((punc is ".")

      ;; This is to distinguish abbreviations vs periods
      ;; These are heuristics
      ((name matches "\\(.*\\..*\\|[A-Z][A-Za-z]?[A-Za-z]?\\|etc\\)")  ;; an abbreviation
       ((n.whitespace is " ")
	((0))                        ;; if abbrev single space isn't enough for break
	((n.name matches "[A-Z].*")
	 ((1))
	 ((0))))

       ((n.whitespace is " ")        ;; if it doesn't look like an abbreviation
	((n.name matches "[A-Z].*")  ;; single space and non-cap is no break
	 ((name matches "[0-9].*")   ;; a number?
	  ((0))
	  ((1)))
	 ((0)))
	((1)))

       )

      ((0))))))



(provide 'ims_german_token)



