;/*************************************************************************/
;/*                                                                       */
;/*                Institut fr Maschinelle Sprachverarbeitung            */
;/*                     University of Stuttgart, Germany                  */
;/*                         Copyright (c) 1998                            */
;/*                        All Rights Reserved.                           */
;/*                                                                       */
;/*  Permission to use, copy, modify, distribute this software and its    */
;/*  documentation for research, educational and individual use only, is  */
;/*  hereby granted without fee, subject to the following conditions:     */
;/*   1. The code must retain the above copyright notice, this list of    */
;/*      conditions and the following disclaimer.                         */
;/*   2. Any modifications must be clearly marked as such.                */
;/*   3. Original authors' names are not deleted.                         */
;/*   4. It may not be redistributed in a modified version or within      */
;/*      another distribution                                             */
;/*  This software may not be used for commercial purposes without        */
;/*  specific prior written permission from the authors.                  */
;/*                                                                       */
;/*  THE UNIVERSITY OF STUTTGART AND THE CONTRIBUTORS TO THIS WORK        */
;/*  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      */
;/*  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   */
;/*  SHALL THE UNIVERSITY OF STUTTGART NOR THE CONTRIBUTORS BE LIABLE     */
;/*  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    */
;/*  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   */
;/*  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          */
;/*  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       */
;/*  THIS SOFTWARE.                                                       */
;/*                                                                       */
;/*************************************************************************/
;/*             Author : Gregor Mhler (moehler@ims.uni-stuttgart.de)     */
;/*-----------------------------------------------------------------------*/
;/*                                                                       */
;/* All German voices of the OpenOurce version are defined in this file.  */
;/* Most of them are based on the MBROLA basevoice                        */
;/* \texttt{basevoice_german_mbrola_os}                                   */
;/*                                                                       */
;/*=======================================================================*/

;;;;;; German basevoice using MBROLA ;;;;;;;;;;;;;;;;;;;;;;
(define (basevoice_german_mbrola_os mbrola_db topbaseline)
  "(basevoice_german_mbrola mbrola_db topbaseline)
   Set up a basic German MBROLA voice with database mbrola_db. 
   Topline and Baseline are given by the topbaseline"

  (voice_reset)
  (Param.set 'Language 'german)

  ;;Utterance-chunking
  (require 'ims_german_token)
  (set! eou_tree german_eou_tree) 

  ;;Tokenizing
  (Param.set 'Token_Method 'Token_German)
  (set! token.punctuation  "\"'`.,:;!?(){}[]-")
  (set! token.prepunctuation "\"'`({[")

  ;;Token_POS-prediction
  (require 'ims_german_tokenpos)
  (set! token_pos_cart_trees german_token_pos_cart_trees) 

  ;; Phrase prediction
  (require 'ims_german_phrasify)
  (Param.set 'Phrasify_Method 'Phrasify_German)
  (set! phrase_cart_tree german_phrase_cart_tree) 
  (Param.set 'Phrase_Method 'cart_tree)

  ;; Phone set
  (require 'ims_german_phones)
  (Param.set 'PhoneSet 'german_sampa)
  (PhoneSet.select 'german_sampa)

  ;; no POS tagger for basic voice
  (Param.set 'POS_Method 'No_POS)
  (Param.set 'pos_tagset 'ustts) ; main categories of the STTS tagset

  ;; Lexicon selection
  (require 'ims_german_lexicons)
  (setup_bomp_lex)
  (lex.select "bomp")
  (require 'ims_german_postlex)
  (set! postlex_rules_hooks german_postlex)

  ;; Accent prediction by a simple CART 
  (require 'ims_german_tobi_rules)
  (Param.set 'Int_Method Intonation_Tree)
  (set! int_accent_cart_tree simple_int_accent_cart_tree)
  (set! int_tone_cart_tree   simple_int_tone_cart_tree)

  ;; F0 Precition: Targets by rules
  (Param.set 'Int_Method 'Intonation_Tree)  
  (Param.set 'Int_Target_Method 'Int_Targets_General)
  ; this causes the function tobi_f0_targets to be used in case Int_Target_Method is Int_Targets_General
  (set! int_general_params
	(list 
	 (list 'targ_func tobi_f0_targets))) 
  (if (not (equal? 4 (length topbaseline))) 
      (error "basevoice_german_mbrola: topbaseline must contain 4 values"))
  (Param.set 'Default_Start_Topline (car topbaseline))  
  (Param.set 'Default_End_Topline (cadr topbaseline))   
  (Param.set 'Default_Start_Baseline (caddr topbaseline))
  (Param.set 'Default_End_Baseline (cadr(cddr topbaseline))) 

  ;; Duration prediction
  (require 'ims_german_duration)
  (Param.set 'Duration_Method 'Tree_ZScores)
  (set! duration_cart_tree german_duration_cart_tree)
  (set! duration_ph_info german_duration_ph_info_sampa)  
  (Param.set 'Duration_Stretch 1.1)

  ;; Waveform synthesizer: MBROLA
  (require 'mbrola)
  (Param.set 'Synth_Method  MBROLA_Synth)
  (set! mbrola_database 
	(string-append mbrola-path "/" mbrola_db "/" mbrola_db))
  (set! mbrola_phonemap_tab german_sampa2german_mbrola_map)

  'basevoice_german_mbrola_os
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; the German OpenSource voices ;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;; proclaim the voices ;;;;;;;;;;;;;;;
(proclaim_voice
 'german_de1
 '((language german)
   (gender female)
   (dialect german)
   (description
    "This voice provides a standard German female voice using the
     MBROLA synthesis method. It uses the Celex lexicon for pronunciations.
     Prosodic phrasing and accentuation uses a simple method. 
     Accentuation uses German ToBI labels that are 
     transfered into Fo with a rule-based method. The
     duration model is trained from data using a CART tree.")))
(proclaim_voice
 'german_de2
 '((language german)
   (gender male)
   (dialect german)
   (description
    "This voice provides a standard German male voice using the
     MBROLA synthesis method. It uses the Celex lexicon for pronunciations.
     Prosodic phrasing and accentuation uses a simple method. 
     Accentuation uses German ToBI labels that are 
     transfered into Fo with a rule-based method. The
     duration model is trained from data using a CART tree.")))
(proclaim_voice
 'german_de3
 '((language german)
   (gender female)
   (dialect german)
   (description
    "This voice provides a standard German female voice using the
     MBROLA synthesis method. It uses the Celex lexicon for pronunciations.
     Prosodic phrasing and accentuation uses a simple method. 
     Accentuation uses German ToBI labels that are 
     transfered into Fo with a rule-based method. The
     duration model is trained from data using a CART tree.")))
(proclaim_voice
 'german_de4
 '((language german)
   (gender male)
   (dialect german)
   (description
    "This voice provides a standard German female voice using the
     MBROLA synthesis method. It uses the Celex lexicon for pronunciations.
     Prosodic phrasing and accentuation uses a simple method.
     Accentuation uses German ToBI labels that are
     transfered into Fo with a rule-based method. The
     duration model is trained from data using a CART tree.")))
(proclaim_voice
 'german_de5
 '((language german)
   (gender female)
   (dialect german)
   (description
    "This voice provides a standard German female voice using the
     MBROLA synthesis method. It uses the Celex lexicon for pronunciations.
     Prosodic phrasing and accentuation uses a simple method.
     Accentuation uses German ToBI labels that are
     transfered into Fo with a rule-based method. The
     duration model is trained from data using a CART tree.")))
(proclaim_voice
 'german_de6
 '((language german)
   (gender male)
   (dialect german)
   (description
    "This voice provides a standard German female voice using the
     MBROLA synthesis method. It uses the Celex lexicon for pronunciations.
     Prosodic phrasing and accentuation uses a simple method.
     Accentuation uses German ToBI labels that are
     transfered into Fo with a rule-based method. The
     duration model is trained from data using a CART tree.")))
(proclaim_voice
 'german_de7
 '((language german)
   (gender female)
   (dialect german)
   (description
    "This voice provides a standard German female voice using the
     MBROLA synthesis method. It uses the Celex lexicon for pronunciations.
     Prosodic phrasing and accentuation uses a simple method.
     Accentuation uses German ToBI labels that are
     transfered into Fo with a rule-based method. The
     duration model is trained from data using a CART tree.")))
(proclaim_voice
 'german_de8
 '((language german)
   (gender male)
   (dialect bavarian)
   (description
    "This voice provides a standard German female voice using the
     MBROLA synthesis method. It uses the Celex lexicon for pronunciations.
     Prosodic phrasing and accentuation uses a simple method.
     Accentuation uses German ToBI labels that are
     transfered into Fo with a rule-based method. The
     duration model is trained from data using a CART tree.")))

;;;;;; define the voices ;;;;;;;;;;;;;;;
(define (voice_german_de1_os)
  "(voice_german_de1_os)
  Set up a basic female German voice with MBROLA database de1."

  (basevoice_german_mbrola_os "de1" '(200 180 160 150))
  'voice_german_de1_os
)

(define (voice_german_de2_os)
  "(voice_german_de2_os)
  Set up a basic male German voice with MBROLA database de2."

  (basevoice_german_mbrola_os "de2" '(110 93 90 85))
  'voice_german_de2_os
)

(define (voice_german_de3_os)
  "(voice_german_de3_os)
  Set up a basic female German voice with MBROLA database de3."

  (basevoice_german_mbrola_os "de3" '(210 190 190 180))
  'voice_german_de3_os
)

(define (voice_german_de4_os)
  "(voice_german_de4_os)
  Set up a basic male German voice with MBROLA database de4."

  (basevoice_german_mbrola_os "de4" '(200 180 160 150))
  'voice_german_de4_os
)

(define (voice_german_de5_os)
  "(voice_german_de5_os)
  Set up a basic female German voice with MBROLA database de5."

  (basevoice_german_mbrola_os "de5" '(110 93 90 85))
  'voice_german_de5_os
)

(define (voice_german_de6_os)
  "(voice_german_de6_os)
  Set up a basic male German voice with MBROLA database de6."

  (basevoice_german_mbrola_os "de6" '(210 190 190 180))
  'voice_german_de6_os
)

(define (voice_german_de7_os)
  "(voice_german_de7_os)
  Set up a basic female German voice with MBROLA database de7."

  (basevoice_german_mbrola_os "de7" '(110 93 90 85))
  'voice_german_de7_os
)

(define (voice_german_de8_os)
  "(voice_german_de8_os)
  Set up a basic male German voice with MBROLA database de8."

  (basevoice_german_mbrola_os "de8" '(210 190 190 180))
  'voice_german_de8_os
)

(provide 'ims_german_voices_opensource)











